@@ -2,6 +2,6 @@
 
 from acp.client.protocol import Client
 from acp.client.default_client import DefaultACPClient
+from acp.client.connection import ClientSideConnection
 
-
-__all__ = ["Client", "DefaultACPClient"]
+__all__ = ["Client", "ClientSideConnection", "DefaultACPClient"]
