@@ -8,12 +8,11 @@ from contextlib import AsyncExitStack, asynccontextmanager
 from dataclasses import dataclass, field
 from os import PathLike
 import time
-from typing import TYPE_CHECKING, Any, Literal, Self, TypedDict, cast, overload
+from typing import TYPE_CHECKING, Any, Literal, Self, TypedDict, TypeVar, cast, overload
 from uuid import uuid4
 
 from llmling import Config, RuntimeConfig, ToolError
 from psygnal import Signal
-from typing_extensions import TypeVar
 
 from llmling_agent.log import get_logger
 from llmling_agent.messaging.messagenode import MessageNode
@@ -71,9 +70,7 @@ if TYPE_CHECKING:
     from llmling_agent_input.base import InputProvider
     from llmling_agent_providers.base import StreamingResponseProtocol, UsageLimits
 
-from llmling_agent_providers.base import (
-    AgentProvider,
-)
+from llmling_agent_providers.base import AgentProvider
 
 
 AgentType = Literal["pydantic_ai", "human"] | AgentProvider | Callable[..., Any]
@@ -81,7 +78,6 @@ AgentType = Literal["pydantic_ai", "human"] | AgentProvider | Callable[..., Any]
 logger = get_logger(__name__)
 
 TResult = TypeVar("TResult", default=str)
-TDeps = TypeVar("TDeps", default=None)
 
 
 class AgentKwargs(TypedDict, total=False):
@@ -98,7 +94,7 @@ class AgentKwargs(TypedDict, total=False):
 
     # Runtime Environment
     runtime: RuntimeConfig | Config | StrPath | None
-    tools: Sequence[ToolType] | None
+    tools: Sequence[ToolType | Tool] | None
     capabilities: Capabilities | None
     mcp_servers: Sequence[str | MCPServerConfig] | None
 
@@ -117,7 +113,7 @@ class AgentKwargs(TypedDict, total=False):
     debug: bool
 
 
-class Agent[TDeps](MessageNode[TDeps, str], TaskManagerMixin):
+class Agent[TDeps = None](MessageNode[TDeps, str], TaskManagerMixin):
     """Agent for AI-powered interaction with LLMling resources and tools.
 
     Generically typed with: LLMLingAgent[Type of Dependencies, Type of Result]
@@ -161,7 +157,7 @@ class Agent[TDeps](MessageNode[TDeps, str], TaskManagerMixin):
         session: SessionIdType | SessionQuery | MemoryConfig | bool | int = None,
         system_prompt: AnyPromptType | Sequence[AnyPromptType] = (),
         description: str | None = None,
-        tools: Sequence[ToolType] | None = None,
+        tools: Sequence[ToolType | Tool] | None = None,
         capabilities: Capabilities | None = None,
         mcp_servers: Sequence[str | MCPServerConfig] | None = None,
         resources: Sequence[Resource | PromptType | str] = (),
@@ -534,7 +530,7 @@ class Agent[TDeps](MessageNode[TDeps, str], TaskManagerMixin):
         return self._provider
 
     @provider.setter
-    def provider(self, value: AgentProvider, model: ModelType = None):
+    def provider(self, value: AgentType, model: ModelType = None):
         """Set the underlying provider."""
         from llmling_agent_providers.base import AgentProvider
 
@@ -651,7 +647,7 @@ class Agent[TDeps](MessageNode[TDeps, str], TaskManagerMixin):
             share_context: Whether to pass parent's context/deps
             parent: Optional parent agent for history/context sharing
         """
-        tool_name = f"ask_{self.name}"
+        tool_name = name or f"ask_{self.name}"
 
         async def wrapped_tool(prompt: str) -> str:
             if pass_message_history and not parent:
@@ -1362,7 +1358,7 @@ if __name__ == "__main__":
     # import logging
 
     sys_prompt = "Open browser with google,"
-    _model = "openai:gpt-5-mini"
+    _model = "openai:gpt-5-nano"
 
     async def main():
         async with Agent[None](model=_model, tools=["webbrowser.open"]) as agent:
