@@ -6,7 +6,6 @@ from collections.abc import Callable, Mapping
 from typing import TYPE_CHECKING, Any, Literal, cast, overload
 
 from schemez import Schema
-from typing_extensions import TypeVar
 
 from llmling_agent.log import get_logger
 from llmling_agent.messaging.messages import ChatMessage
@@ -22,8 +21,7 @@ if TYPE_CHECKING:
     from llmling_agent.agent import AnyAgent
     from llmling_agent.delegation.base_team import BaseTeam
 
-TResult = TypeVar("TResult", default=str)
-TDeps = TypeVar("TDeps", default=None)
+
 ExtractionMode = Literal["structured", "tool_calls"]
 
 type EndCondition = Callable[[list[ChatMessage[Any]], ChatMessage[Any]], bool]
@@ -403,7 +401,7 @@ List your selections, one per line, followed by your reasoning."""
             prompt: Optional custom prompt
             include_tools: Whether to include other tools (tool_calls mode only)
         """
-        from py2openai import create_constructor_schema
+        from schemez import create_constructor_schema
 
         # Create model for single instance
         item_model = Schema.for_class_ctor(as_type)
@@ -465,7 +463,7 @@ List your selections, one per line, followed by your reasoning."""
             prompt: Optional custom prompt
             include_tools: Whether to include other tools (tool_calls mode only)
         """
-        from py2openai import create_constructor_schema
+        from schemez import create_constructor_schema
 
         item_model = Schema.for_class_ctor(as_type)
 
