@@ -64,11 +64,7 @@ class ConnectionManager:
         """Forward message flow to our aggregated signal."""
         self.connection_processed.emit(event)
 
-    def set_wait_state(
-        self,
-        target: MessageEmitter | AgentName,
-        wait: bool = True,
-    ):
+    def set_wait_state(self, target: MessageEmitter | AgentName, wait: bool = True):
         """Set waiting behavior for target."""
         target_name = target if isinstance(target, str) else target.name
         self._wait_states[target_name] = wait
@@ -106,10 +102,10 @@ class ConnectionManager:
 
         for target in targets:
             if target.name not in seen:
-                _targets = target.connections.get_targets(recursive=True, _seen=seen)
+                targets_ = target.connections.get_targets(recursive=True, _seen=seen)
                 seen.add(target.name)
                 all_targets.add(target)
-                all_targets.update(_targets)
+                all_targets.update(targets_)
 
         return all_targets
 
