@@ -9,12 +9,12 @@ from typing import TYPE_CHECKING, Any
 
 
 if TYPE_CHECKING:
-    from llmling_agent.delegation.pool import AgentPool
+    from llmling_agent import AgentPool
     from llmling_agent.messaging.messageemitter import MessageEmitter
     from llmling_agent.models.manifest import AgentsManifest
-    from llmling_agent.models.nodes import NodeConfig
     from llmling_agent.prompts.manager import PromptManager
     from llmling_agent.storage import StorageManager
+    from llmling_agent_config.nodes import NodeConfig
     from llmling_agent_input.base import InputProvider
 
 
@@ -23,10 +23,12 @@ ProgressCallback = Callable[[float, float | None], Awaitable[None]]
 
 @dataclass(kw_only=True)
 class NodeContext[TDeps]:
+    """Context for message processing nodes."""
+
     node_name: str
     """Name of the current node."""
 
-    pool: AgentPool | None = None
+    pool: AgentPool[Any] | None = None
     """The agent pool the node is part of."""
 
     config: NodeConfig
