@@ -23,7 +23,7 @@ if TYPE_CHECKING:
 
 
 logger = get_logger(__name__)
-DEFAULT_TOKEN_MODEL = "gpt-3.5-turbo"
+DEFAULT_TOKEN_MODEL = "gpt-4.1"
 
 
 class ChatMessageContainer(EventedList[ChatMessage[Any]]):
@@ -89,12 +89,7 @@ class ChatMessageContainer(EventedList[ChatMessage[Any]]):
         """Get most recent message or None if empty."""
         return self[-1] if self else None
 
-    def format(
-        self,
-        *,
-        style: FormatStyle = "simple",
-        **kwargs: Any,
-    ) -> str:
+    def format(self, *, style: FormatStyle = "simple", **kwargs: Any) -> str:
         """Format conversation history with configurable style.
 
         Args:
