@@ -15,10 +15,10 @@ from llmling_agent_config.converters import ConversionConfig
 from llmling_agent_config.mcp_server import (
     BaseMCPServerConfig,
     MCPServerConfig,  # noqa: TC001
-    PoolServerConfig,
     StdioMCPServerConfig,
 )
 from llmling_agent_config.observability import ObservabilityConfig
+from llmling_agent_config.pool_server import MCPPoolServerConfig
 from llmling_agent_config.prompts import PromptConfig
 from llmling_agent_config.providers import BaseProviderConfig
 from llmling_agent_config.resources import (  # noqa: TC001
@@ -103,7 +103,7 @@ class AgentsManifest(Schema):
 
     These MCP servers are used to provide tools and other resources to the nodes.
     """
-    pool_server: PoolServerConfig = Field(default_factory=PoolServerConfig)
+    pool_server: MCPPoolServerConfig = Field(default_factory=MCPPoolServerConfig)
     """Pool server configuration.
 
     This MCP server configuration is used for the pool MCP server,
