@@ -3,10 +3,9 @@
 from __future__ import annotations
 
 from collections import defaultdict
-from collections.abc import Callable, Iterator, Sequence
+from collections.abc import Callable, Sequence
 from contextlib import asynccontextmanager
 from dataclasses import dataclass, field, replace
-from datetime import datetime
 from typing import TYPE_CHECKING, Any, Self, overload
 
 from psygnal import Signal
@@ -15,11 +14,12 @@ from llmling_agent.log import get_logger
 from llmling_agent.messaging.messages import ChatMessage
 from llmling_agent.talk.stats import AggregatedTalkStats, TalkStats
 from llmling_agent.utils.inspection import execute
+from llmling_agent.utils.now import get_now
 
 
 if TYPE_CHECKING:
-    from collections.abc import Awaitable
-    from datetime import timedelta
+    from collections.abc import Awaitable, Iterator
+    from datetime import datetime, timedelta
     import os
 
     import PIL.Image
@@ -29,9 +29,9 @@ if TYPE_CHECKING:
     from llmling_agent.messaging.events import ConnectionEventData, EventData
     from llmling_agent.messaging.messageemitter import MessageEmitter
     from llmling_agent.messaging.messagenode import MessageNode
-    from llmling_agent.models.events import ConnectionEventType
-    from llmling_agent.models.forward_targets import ConnectionType
-    from llmling_agent.models.providers import ProcessorCallback
+    from llmling_agent_config.events import ConnectionEventType
+    from llmling_agent_config.forward_targets import ConnectionType
+    from llmling_agent_config.providers import ProcessorCallback
 
 logger = get_logger(__name__)
 
@@ -48,7 +48,7 @@ class Talk[TTransmittedData]:
         targets: list[MessageNode]
         queued: bool
         connection_type: ConnectionType
-        timestamp: datetime = field(default_factory=datetime.now)
+        timestamp: datetime = field(default_factory=get_now)
 
     # Original message "coming in"
     message_received = Signal(ChatMessage)
@@ -153,8 +153,7 @@ class Talk[TTransmittedData]:
             connection >> other_agent  # Connect to single agent
             connection >> (agent2 & agent3)  # Connect to group
         """
-        from llmling_agent.agent import Agent, StructuredAgent
-        from llmling_agent.messaging.messagenode import MessageNode
+        from llmling_agent import Agent, MessageNode, StructuredAgent
         from llmling_agent.talk import TeamTalk
         from llmling_agent.utils.inspection import has_return_type
 
@@ -234,7 +233,7 @@ class Talk[TTransmittedData]:
             connection_name=self.name,
             event_type=event_type,
             message=message,
-            timestamp=datetime.now(),
+            timestamp=get_now(),
         )
         # Propagate to all event managers through registry
         if self.source.context and (pool := self.source.context.pool):
@@ -524,8 +523,7 @@ class TeamTalk[TTransmittedData](list["Talk | TeamTalk"]):
             connection >> other_agent  # Connect to single agent
             connection >> (agent2 & agent3)  # Connect to group
         """
-        from llmling_agent.agent import Agent, StructuredAgent
-        from llmling_agent.messaging.messagenode import MessageNode
+        from llmling_agent import Agent, MessageNode, StructuredAgent
         from llmling_agent.talk import TeamTalk
         from llmling_agent.utils.inspection import has_return_type
 
