@@ -5,7 +5,6 @@ from __future__ import annotations
 from collections.abc import Callable, Sequence
 from contextlib import contextmanager
 from dataclasses import dataclass, field, fields
-from datetime import datetime
 from typing import TYPE_CHECKING, Any, Literal
 
 from llmling import BaseRegistry, LLMCallableTool, ToolError
@@ -15,22 +14,26 @@ from psygnal import Signal
 from llmling_agent.log import get_logger
 from llmling_agent.resource_providers.callable_provider import (
     CallableResourceProvider,
-    ResourceCallable,
 )
 from llmling_agent.tools.base import Tool
+from llmling_agent.utils.now import get_now
 
 
 if TYPE_CHECKING:
     from collections.abc import Iterator
+    from datetime import datetime
 
-    from llmling_agent.agent import AnyAgent
+    from llmling_agent import AnyAgent, MessageNode
     from llmling_agent.common_types import AnyCallable, ToolSource, ToolType
     from llmling_agent.resource_providers.base import ResourceProvider
+    from llmling_agent.resource_providers.callable_provider import (
+        ResourceCallable,
+    )
 
 
 logger = get_logger(__name__)
 
-MAX_LEN_DESCRIPTION = 1000
+MAX_LEN_DESCRIPTION = 2000
 ToolState = Literal["all", "enabled", "disabled"]
 ProviderName = str
 OwnerType = Literal["pool", "team", "node"]
@@ -55,7 +58,7 @@ class ToolManager(BaseRegistry[str, Tool]):
 
         previous_tools: dict[str, bool]
         new_tools: dict[str, bool]
-        timestamp: datetime = field(default_factory=datetime.now)
+        timestamp: datetime = field(default_factory=get_now)
 
     tool_states_reset = Signal(ToolStateReset)
 
@@ -158,22 +161,10 @@ class ToolManager(BaseRegistry[str, Tool]):
                 return Tool.from_callable(item)
             case Callable():
                 return Tool.from_callable(item)
-            case {"callable": callable_item, **config} if callable(
-                callable_item
-            ) or isinstance(callable_item, LLMCallableTool):
-                # First convert callable to LLMCallableTool if needed
-                tool = (
-                    callable_item
-                    if isinstance(callable_item, LLMCallableTool)
-                    else LLMCallableTool.from_callable(callable_item)
-                )
-
-                # Get valid fields from Tool dataclass (excluding 'callable')
+            case {"callable": callable_item, **config} if callable(callable_item):
                 valid_keys = {f.name for f in fields(Tool)} - {"callable"}
                 tool_config = {k: v for k, v in config.items() if k in valid_keys}
-
-                return Tool(callable=tool, **tool_config)  # type: ignore
-
+                return Tool.from_callable(callable_item, **tool_config)  # type: ignore
             case _:
                 typ = type(item)
                 msg = f"Item must be Tool or callable. Got {typ}"
@@ -210,13 +201,15 @@ class ToolManager(BaseRegistry[str, Tool]):
     async def get_tools(
         self,
         state: ToolState = "all",
+        names: str | list[str] | None = None,
     ) -> list[Tool]:
         """Get tool objects based on filters."""
-        tools: list[Tool] = []
-
-        # Get tools from registry
-        tools.extend(t for t in self.values() if t.matches_filter(state))
-
+        tools = [t for t in self.values() if t.matches_filter(state)]
+        match names:
+            case str():
+                tools = [t for t in tools if t.name == names]
+            case list():
+                tools = [t for t in tools if t.name in names]
         # Get tools from providers
         for provider in self.providers:
             try:
@@ -299,7 +292,7 @@ class ToolManager(BaseRegistry[str, Tool]):
 
     def register_worker(
         self,
-        worker: AnyAgent[Any, Any],
+        worker: MessageNode[Any, Any],
         *,
         name: str | None = None,
         reset_history_on_run: bool = True,
@@ -317,13 +310,22 @@ class ToolManager(BaseRegistry[str, Tool]):
             share_context: Whether to pass parent's context/deps
             parent: Optional parent agent for history/context sharing
         """
-        tool = worker.to_tool(
-            parent=parent,
-            name=name,
-            reset_history_on_run=reset_history_on_run,
-            pass_message_history=pass_message_history,
-            share_context=share_context,
-        )
+        from llmling_agent import Agent, BaseTeam, StructuredAgent
+
+        match worker:
+            case BaseTeam():
+                tool = worker.to_tool(name=name)
+            case Agent() | StructuredAgent():
+                tool = worker.to_tool(
+                    parent=parent,
+                    name=name,
+                    reset_history_on_run=reset_history_on_run,
+                    pass_message_history=pass_message_history,
+                    share_context=share_context,
+                )
+            case _:
+                msg = f"Unsupported worker type: {type(worker)}"
+                raise ValueError(msg)
         msg = "Registering worker %s as tool %s"
         logger.debug(msg, worker.name, tool.name)
         return self.register_tool(tool, source="agent", metadata={"agent": worker.name})
