@@ -9,18 +9,23 @@ from typing import TYPE_CHECKING, Any
 
 from pydantic_ai import RunContext  # noqa: TC002
 
+from acp.acp_types import PlanEntryPriority, PlanEntryStatus  # noqa: TC001
 from acp.schema import (
+    AgentPlan,
     ContentToolCallContent,
     CreateTerminalRequest,
     EnvVariable,
     KillTerminalCommandRequest,
+    PlanEntry,
     ReadTextFileRequest,
     ReleaseTerminalRequest,
     SessionNotification,
     TerminalOutputRequest,
+    TerminalToolCallContent,
     TextContentBlock,
     ToolCallLocation,
     ToolCallProgress,
+    ToolCallStart,
     WaitForTerminalExitRequest,
     WriteTextFileRequest,
 )
@@ -65,6 +70,7 @@ class ACPCapabilityResourceProvider(ResourceProvider):
         self.session_id = session_id
         self.client_capabilities = client_capabilities
         self.cwd = cwd
+        self._current_plan: list[PlanEntry] = []
 
     def _resolve_path(self, path: str) -> str:
         """Resolve a potentially relative path to an absolute path.
@@ -88,6 +94,9 @@ class ACPCapabilityResourceProvider(ResourceProvider):
         """Get tools based on client capabilities."""
         tools: list[Tool] = []
 
+        # Plan tools - always available for ACP sessions
+        tools.extend(self._get_plan_tools())
+
         # Terminal tools if supported by both client and agent
         if self.client_capabilities.terminal and self.agent.terminal_access:
             tools.extend(self._get_terminal_tools())
@@ -153,17 +162,12 @@ class ACPCapabilityResourceProvider(ResourceProvider):
                 source="terminal",
                 name_override="release_terminal",
             ),
-            Tool.from_callable(
-                self._create_run_command_with_timeout_tool(),
-                source="terminal",
-                name_override="run_command_with_timeout",
-            ),
         ]
 
     # Terminal Tool Implementations
 
     def _create_run_command_tool(self):
-        """Create a tool that runs commands via the ACP client."""
+        """Create a tool that runs commands with live terminal output."""
 
         async def run_command(  # noqa: D417
             ctx: RunContext[Any],
@@ -172,51 +176,121 @@ class ACPCapabilityResourceProvider(ResourceProvider):
             cwd: str | None = None,
             env: dict[str, str] | None = None,
             output_char_limit: int | None = None,
+            timeout_seconds: int | None = None,
         ) -> str:
-            r"""Execute a shell command and return its output.
+            r"""Execute a shell command with live terminal output visible to the user.
 
-            Use this tool when you need to run a command and see its complete output.
-            This handles the full lifecycle: creates terminal, runs command,
-            waits for completion, captures output, and cleans up automatically.
+            This tool shows real-time command output in the UI as it happens,
+            perfect for long-running commands like builds, tests, or installations.
 
             Args:
-                command: The command to execute (e.g., 'echo', 'ls', 'python')
-                args: Command arguments as list (e.g., ['hello world'] for echo)
+                command: The command to execute (e.g., 'npm', 'python', 'make')
+                args: Command arguments as list (e.g., ['test', '--coverage'])
                 cwd: Working directory path
                 env: Environment variables as key-value pairs
-                output_char_limit: Maximum number of characters to capture from output
+                output_char_limit: Maximum output characters to retain
+                timeout_seconds: Maximum time to wait for command completion
 
             Returns:
-                Complete command output including stdout/stderr and exit status
+                Command completion status and any final output
             """
-            create_request = CreateTerminalRequest(
-                session_id=self.session_id,
-                command=command,
-                args=args or [],
-                cwd=cwd,
-                env=[EnvVariable(name=k, value=v) for k, v in (env or {}).items()],
-                output_byte_limit=output_char_limit,
+            # Send initial tool call notification
+            assert ctx.tool_call_id, (
+                "Tool call ID must be present for terminal operations"
             )
+
             try:
+                # Create terminal
+                create_request = CreateTerminalRequest(
+                    session_id=self.session_id,
+                    command=command,
+                    args=args or [],
+                    cwd=cwd,
+                    env=[EnvVariable(name=k, value=v) for k, v in (env or {}).items()],
+                    output_byte_limit=output_char_limit,
+                )
+
                 create_response = await self.agent.connection.create_terminal(
                     create_request
                 )
-                logger.info("🔧 DEBUG: Got create_response: %s", create_response)
                 terminal_id = create_response.terminal_id
-                logger.info("🔧 DEBUG: Extracted terminal_id: %s", terminal_id)
 
-                # Wait for completion
-                logger.info("🔧 DEBUG: Creating wait_request")
+                # Send initial notification with embedded terminal for live output
+                cmd_display = f"{command} {' '.join(args or [])}"
+                initial_update = SessionNotification(
+                    session_id=self.session_id,
+                    update=ToolCallStart(
+                        tool_call_id=ctx.tool_call_id,
+                        status="pending",
+                        title=f"Running: {cmd_display}",
+                        kind="execute",
+                        content=[TerminalToolCallContent(terminal_id=terminal_id)],
+                    ),
+                )
+                await self.agent.connection.session_update(initial_update)
+
+                # Wait for completion (with optional timeout)
                 wait_request = WaitForTerminalExitRequest(
                     session_id=self.session_id,
                     terminal_id=terminal_id,
                 )
-                logger.info("🔧 DEBUG: Calling wait_for_terminal_exit")
-                await self.agent.connection.wait_for_terminal_exit(wait_request)
-                logger.info("🔧 DEBUG: Terminal exit completed")
 
-                # Get output
-                logger.info("🔧 DEBUG: Getting terminal output")
+                if timeout_seconds:
+                    import asyncio
+
+                    try:
+                        exit_result = await asyncio.wait_for(
+                            self.agent.connection.wait_for_terminal_exit(wait_request),
+                            timeout=timeout_seconds,
+                        )
+                    except TimeoutError:
+                        # Kill the command on timeout
+                        kill_request = KillTerminalCommandRequest(
+                            session_id=self.session_id,
+                            terminal_id=terminal_id,
+                        )
+                        await self.agent.connection.kill_terminal(kill_request)
+
+                        # Get output before releasing
+                        output_request = TerminalOutputRequest(
+                            session_id=self.session_id,
+                            terminal_id=terminal_id,
+                        )
+                        output_response = await self.agent.connection.terminal_output(
+                            output_request
+                        )
+
+                        # Send timeout notification
+                        timeout_update = SessionNotification(
+                            session_id=self.session_id,
+                            update=ToolCallProgress(
+                                tool_call_id=ctx.tool_call_id,
+                                status="failed",
+                                title=f"Command timed out after {timeout_seconds}s",
+                                content=[
+                                    TerminalToolCallContent(terminal_id=terminal_id)
+                                ],
+                            ),
+                        )
+                        await self.agent.connection.session_update(timeout_update)
+
+                        # Release terminal
+                        release_request = ReleaseTerminalRequest(
+                            session_id=self.session_id,
+                            terminal_id=terminal_id,
+                        )
+                        await self.agent.connection.release_terminal(release_request)
+
+                        return (
+                            f"Command timed out after {timeout_seconds} seconds. "
+                            f"Output: \n{output_response.output}"
+                        )
+                else:
+                    exit_result = await self.agent.connection.wait_for_terminal_exit(
+                        wait_request
+                    )
+
+                # Get final output
                 output_request = TerminalOutputRequest(
                     session_id=self.session_id,
                     terminal_id=terminal_id,
@@ -224,27 +298,47 @@ class ACPCapabilityResourceProvider(ResourceProvider):
                 output_response = await self.agent.connection.terminal_output(
                     output_request
                 )
-                logger.info("🔧 DEBUG: Got output response")
 
-                # Release terminal
-                logger.info("🔧 DEBUG: Releasing terminal")
+                # Send completion notification (terminal remains embedded for viewing)
+                status = "completed" if (exit_result.exit_code or 0) == 0 else "failed"
+                exit_code = exit_result.exit_code or 0
+
+                completion_update = SessionNotification(
+                    session_id=self.session_id,
+                    update=ToolCallProgress(
+                        tool_call_id=ctx.tool_call_id,
+                        status=status,
+                        title=f"Command completed (exit code: {exit_code})",
+                        content=[TerminalToolCallContent(terminal_id=terminal_id)],
+                    ),
+                )
+                await self.agent.connection.session_update(completion_update)
+
+                # Release terminal (output remains visible in UI)
                 release_request = ReleaseTerminalRequest(
                     session_id=self.session_id,
                     terminal_id=terminal_id,
                 )
                 await self.agent.connection.release_terminal(release_request)
-                logger.info("🔧 DEBUG: Terminal released")
-
-                result = output_response.output
-                if output_response.exit_status:
-                    code = output_response.exit_status.exit_code
-                    if code is not None:
-                        result += f"\n[Command exited with code {code}]"
-                    if output_response.exit_status.signal:
-                        signal = output_response.exit_status.signal
-                        result += f"\n[Terminated by signal {signal}]"
-
+                result = f"Command completed with exit code {exit_code}:\n"
+                result += f"Output:\n{output_response.output}"
+                if output_response.truncated:
+                    result += " (output was truncated)"
             except Exception as e:  # noqa: BLE001
+                # Send error notification
+                error_update = SessionNotification(
+                    session_id=self.session_id,
+                    update=ToolCallProgress(
+                        tool_call_id=ctx.tool_call_id,
+                        status="failed",
+                        title=f"Command failed: {e}",
+                    ),
+                )
+                try:
+                    await self.agent.connection.session_update(error_update)
+                except Exception:  # noqa: BLE001
+                    logger.warning("Failed to send error update")
+
                 return f"Error executing command: {e}"
             else:
                 return result
@@ -580,6 +674,21 @@ class ACPCapabilityResourceProvider(ResourceProvider):
             # Resolve relative paths against session cwd
             resolved_path = self._resolve_path(path)
 
+            # Send initial pending notification
+            assert ctx.tool_call_id, "Tool call ID must be present for fs operations"
+            try:
+                start = ToolCallStart(
+                    tool_call_id=ctx.tool_call_id,
+                    status="pending",
+                    title=f"Reading file: {path}",
+                    kind="read",
+                    locations=[ToolCallLocation(path=resolved_path)],
+                )
+                notifi = SessionNotification(session_id=self.session_id, update=start)
+                await self.agent.connection.session_update(notifi)
+            except Exception as e:  # noqa: BLE001
+                logger.warning("Failed to send pending update: %s", e)
+
             request = ReadTextFileRequest(
                 session_id=self.session_id,
                 path=resolved_path,
@@ -592,23 +701,16 @@ class ACPCapabilityResourceProvider(ResourceProvider):
 
                 # Send completion update
                 assert ctx.tool_call_id, "Tool call ID must be present for fs operations"
+                block = TextContentBlock(text=f"````\n{response.content}\n````")
+                progress = ToolCallProgress(
+                    tool_call_id=ctx.tool_call_id,
+                    status="completed",
+                    locations=[ToolCallLocation(path=resolved_path)],
+                    content=[ContentToolCallContent(content=block)],
+                )
+                notifi = SessionNotification(session_id=self.session_id, update=progress)
                 try:
-                    completed_update = SessionNotification(
-                        session_id=self.session_id,
-                        update=ToolCallProgress(
-                            tool_call_id=ctx.tool_call_id,
-                            status="completed",
-                            locations=[ToolCallLocation(path=resolved_path)],
-                            content=[
-                                ContentToolCallContent(
-                                    content=TextContentBlock(
-                                        text=f"````\n{response.content}\n````"
-                                    )
-                                )
-                            ],
-                        ),
-                    )
-                    await self.agent.connection.session_update(completed_update)
+                    await self.agent.connection.session_update(notifi)
                 except Exception as e:  # noqa: BLE001
                     logger.warning("Failed to send completed update: %s", e)
 
@@ -638,19 +740,35 @@ class ACPCapabilityResourceProvider(ResourceProvider):
         async def write_text_file(ctx: RunContext[Any], path: str, content: str) -> str:  # noqa: D417
             r"""Write text content to a file, creating or overwriting as needed.
 
-            Use this to create configuration files, save data, write scripts,
-            or update any text-based files on the client's filesystem.
-
             Args:
                 path: File path (absolute or relative to session cwd)
-                content: The complete text content to write to the file
+                content: Text content to write to the file
 
             Returns:
-                Success confirmation message, or error message if write fails
+                Success message or error description
+
+            Example:
+                write_text_file('config.json', '{"debug": true}') ->
+                'Successfully wrote file: config.json'
             """
             # Resolve relative paths against session cwd
             resolved_path = self._resolve_path(path)
 
+            # Send initial pending notification
+            assert ctx.tool_call_id, "Tool call ID must be present for fs operations"
+            try:
+                update = ToolCallStart(
+                    tool_call_id=ctx.tool_call_id,
+                    status="pending",
+                    title=f"Writing file: {path}",
+                    kind="edit",
+                    locations=[ToolCallLocation(path=resolved_path)],
+                )
+                noti = SessionNotification(session_id=self.session_id, update=update)
+                await self.agent.connection.session_update(noti)
+            except Exception as e:  # noqa: BLE001
+                logger.warning("Failed to send pending update: %s", e)
+
             request = WriteTextFileRequest(
                 session_id=self.session_id,
                 path=resolved_path,
@@ -663,22 +781,16 @@ class ACPCapabilityResourceProvider(ResourceProvider):
                 # Send completion update
                 assert ctx.tool_call_id, "Tool call ID must be present for fs operations"
                 try:
-                    completed_update = SessionNotification(
-                        session_id=self.session_id,
-                        update=ToolCallProgress(
-                            tool_call_id=ctx.tool_call_id,
-                            status="completed",
-                            locations=[ToolCallLocation(path=resolved_path)],
-                            content=[
-                                ContentToolCallContent(
-                                    content=TextContentBlock(
-                                        text=f"Successfully wrote file: {path}"
-                                    )
-                                )
-                            ],
-                        ),
+                    block = TextContentBlock(text=content)
+                    tool_content = ContentToolCallContent(content=block)
+                    progress = ToolCallProgress(
+                        tool_call_id=ctx.tool_call_id,
+                        status="completed",
+                        locations=[ToolCallLocation(path=resolved_path)],
+                        content=[tool_content],
                     )
-                    await self.agent.connection.session_update(completed_update)
+                    s = SessionNotification(session_id=self.session_id, update=progress)
+                    await self.agent.connection.session_update(s)
                 except Exception as e:  # noqa: BLE001
                     logger.warning("Failed to send completed update: %s", e)
 
@@ -686,15 +798,13 @@ class ACPCapabilityResourceProvider(ResourceProvider):
                 # Send failed update
                 assert ctx.tool_call_id, "Tool call ID must be present for fs operations"
                 try:
-                    failed_update = SessionNotification(
-                        session_id=self.session_id,
-                        update=ToolCallProgress(
-                            tool_call_id=ctx.tool_call_id,
-                            status="failed",
-                            raw_output=f"Error: {e}",
-                        ),
+                    progress = ToolCallProgress(
+                        tool_call_id=ctx.tool_call_id,
+                        status="failed",
+                        raw_output=f"Error: {e}",
                     )
-                    await self.agent.connection.session_update(failed_update)
+                    s = SessionNotification(session_id=self.session_id, update=progress)
+                    await self.agent.connection.session_update(s)
                 except Exception:  # noqa: BLE001
                     logger.warning("Failed to send failed update")
 
@@ -703,3 +813,159 @@ class ACPCapabilityResourceProvider(ResourceProvider):
                 return f"Successfully wrote file: {path}"
 
         return write_text_file
+
+    def _get_plan_tools(self) -> list[Tool]:
+        """Get plan management tools."""
+        return [
+            Tool.from_callable(
+                self._create_add_plan_entry_tool(),
+                source="planning",
+                name_override="add_plan_entry",
+            ),
+            Tool.from_callable(
+                self._create_update_plan_entry_tool(),
+                source="planning",
+                name_override="update_plan_entry",
+            ),
+            Tool.from_callable(
+                self._create_remove_plan_entry_tool(),
+                source="planning",
+                name_override="remove_plan_entry",
+            ),
+        ]
+
+    def _create_add_plan_entry_tool(self):
+        """Create add plan entry tool."""
+
+        async def add_plan_entry(
+            content: str,
+            priority: PlanEntryPriority = "medium",
+            index: int | None = None,
+        ) -> str:
+            """Add a new plan entry.
+
+            Args:
+                content: Description of what this task aims to accomplish
+                priority: Relative importance (high/medium/low)
+                index: Optional position to insert at (default: append to end)
+
+            Returns:
+                Success message indicating entry was added
+            """
+            entry = PlanEntry(
+                content=content,
+                priority=priority,
+                status="pending",
+            )
+
+            if index is None:
+                self._current_plan.append(entry)
+                entry_index = len(self._current_plan) - 1
+            else:
+                if index < 0 or index > len(self._current_plan):
+                    return (
+                        f"Error: Index {index} out of range (0-{len(self._current_plan)})"
+                    )
+                self._current_plan.insert(index, entry)
+                entry_index = index
+
+            # Send plan update
+            await self._send_plan_update()
+
+            return (
+                f"Added plan entry at index {entry_index}: "
+                f"'{content}' (priority: {priority})"
+            )
+
+        return add_plan_entry
+
+    def _create_update_plan_entry_tool(self):
+        """Create update plan entry tool."""
+
+        async def update_plan_entry(
+            index: int,
+            content: str | None = None,
+            status: PlanEntryStatus | None = None,
+            priority: PlanEntryPriority | None = None,
+        ) -> str:
+            """Update an existing plan entry.
+
+            Args:
+                index: Position of entry to update (0-based)
+                content: New task description
+                status: New execution status
+                priority: New priority level
+
+            Returns:
+                Success message indicating what was updated
+            """
+            if index < 0 or index >= len(self._current_plan):
+                return (
+                    f"Error: Index {index} out of range (0-{len(self._current_plan) - 1})"
+                )
+
+            entry = self._current_plan[index]
+            updates = []
+
+            if content is not None:
+                entry.content = content
+                updates.append(f"content to '{content}'")
+
+            if status is not None:
+                entry.status = status
+                updates.append(f"status to '{status}'")
+
+            if priority is not None:
+                entry.priority = priority
+                updates.append(f"priority to '{priority}'")
+
+            if not updates:
+                return "No changes specified"
+
+            # Send plan update
+            await self._send_plan_update()
+
+            return f"Updated entry {index}: {', '.join(updates)}"
+
+        return update_plan_entry
+
+    def _create_remove_plan_entry_tool(self):
+        """Create remove plan entry tool."""
+
+        async def remove_plan_entry(index: int) -> str:
+            """Remove a plan entry.
+
+            Args:
+                index: Position of entry to remove (0-based)
+
+            Returns:
+                Success message indicating entry was removed
+            """
+            if index < 0 or index >= len(self._current_plan):
+                return (
+                    f"Error: Index {index} out of range (0-{len(self._current_plan) - 1})"
+                )
+
+            removed_entry = self._current_plan.pop(index)
+
+            # Send plan update
+            await self._send_plan_update()
+
+            if self._current_plan:
+                return (
+                    f"Removed entry {index}: '{removed_entry.content}', "
+                    f"remaining entries reindexed"
+                )
+            return f"Removed entry {index}: '{removed_entry.content}', plan is now empty"
+
+        return remove_plan_entry
+
+    async def _send_plan_update(self):
+        """Send current plan state via session update."""
+        if not self._current_plan:
+            # Don't send empty plans
+            return
+
+        plan = AgentPlan(entries=self._current_plan)
+        notification = SessionNotification(session_id=self.session_id, update=plan)
+        await self.agent.connection.session_update(notification)
