@@ -33,7 +33,7 @@ from llmling_agent_acp.converters import (
 
 # Tools that send their own rich ACP notifications (with ToolCallLocation, etc.)
 # These tools are excluded from generic session-level notifications to prevent duplication
-ACP_SELF_NOTIFYING_TOOLS = {"read_text_file", "write_text_file"}
+ACP_SELF_NOTIFYING_TOOLS = {"read_text_file", "write_text_file", "run_command"}
 
 
 if TYPE_CHECKING:
@@ -143,7 +143,24 @@ class ACPSession:
         cfgs = [convert_acp_mcp_server_to_config(s) for s in self.mcp_servers]
         # Initialize MCP manager with converted configs
         name = f"session_{self.session_id}"
-        self.mcp_manager = MCPManager(name, servers=cfgs, context=self.agent.context)
+
+        # Create progress handler for MCP to ACP bridging
+        from llmling_agent_acp.mcp_progress import create_acp_progress_handler
+
+        progress_handler = create_acp_progress_handler(self)
+
+        # Define accessible roots for MCP servers
+        accessible_roots = []
+        if self.cwd:
+            accessible_roots.append(str(self.cwd))
+
+        self.mcp_manager = MCPManager(
+            name,
+            servers=cfgs,
+            context=self.agent.context,
+            progress_handler=progress_handler,
+            accessible_roots=accessible_roots,
+        )
         try:
             # Start MCP manager and, fetch and add tools
             await self.mcp_manager.__aenter__()
@@ -158,10 +175,11 @@ class ACPSession:
                 msg = "Registered MCP tool %s with schema: %s"
                 logger.debug(msg, tool.name, tool.schema)
 
-            # Commands will be sent after session creation is complete
+            # Register MCP prompts as slash commands
+            await self._register_mcp_prompts_as_commands()
 
         except Exception:
-            msg = "Failed to initialize MCP servers for session %s"
+            msg = "Failed to initialize MCP manager for session %s"
             logger.exception(msg, self.session_id)
             # Don't fail session creation, just log the error
             self.mcp_manager = None
@@ -808,3 +826,31 @@ class ACPSession:
         except Exception:
             msg = "Failed to update available commands for session %s"
             logger.exception(msg, self.session_id)
+
+    async def _register_mcp_prompts_as_commands(self) -> None:
+        """Register MCP prompts as slash commands."""
+        if not self.mcp_manager or not self.command_bridge:
+            return
+
+        try:
+            # Collect all prompts from all MCP clients
+            all_prompts = []
+            for client in self.mcp_manager.clients.values():
+                try:
+                    result = await client.list_prompts()
+                    all_prompts.extend(result.prompts)
+                except Exception as e:  # noqa: BLE001
+                    logger.warning("Failed to list prompts from MCP client: %s", e)
+
+            # Register prompts as commands
+            if all_prompts:
+                self.command_bridge.add_mcp_prompt_commands(all_prompts)
+                msg = "Registered %d MCP prompts as slash commands for session %s"
+                logger.info(msg, len(all_prompts), self.session_id)
+
+                # Send updated command list to client
+                await self.send_available_commands_update()
+
+        except Exception:
+            msg = "Failed to register MCP prompts as commands for session %s"
+            logger.exception(msg, self.session_id)
