@@ -64,136 +64,6 @@ class TestACPCapabilityProvider:
             file_access=True,
         )
 
-    @pytest.fixture
-    def full_capabilities(self):
-        """Client capabilities with all features enabled."""
-        return ClientCapabilities(
-            fs=FileSystemCapability(read_text_file=True, write_text_file=True),
-            terminal=True,
-        )
-
-    @pytest.fixture
-    def terminal_only_capabilities(self):
-        """Client capabilities with only terminal enabled."""
-        return ClientCapabilities(
-            terminal=True,
-        )
-
-    @pytest.fixture
-    def fs_only_capabilities(self):
-        """Client capabilities with only filesystem enabled."""
-        return ClientCapabilities(
-            fs=FileSystemCapability(read_text_file=True, write_text_file=True),
-        )
-
-    @pytest.fixture
-    def no_capabilities(self):
-        """Client capabilities with no features enabled."""
-        return ClientCapabilities()
-
-    async def test_provider_creates_all_tools_with_full_capabilities(
-        self, acp_agent: LLMlingACPAgent, full_capabilities: ClientCapabilities
-    ):
-        """Test provider creates all tools when client has full capabilities."""
-        provider = ACPCapabilityResourceProvider(
-            agent=acp_agent,
-            session_id="test_session",
-            client_capabilities=full_capabilities,
-        )
-
-        tools = await provider.get_tools()
-        tool_names = {tool.name for tool in tools}
-
-        # Should have all terminal tools
-        expected_terminal_tools = {
-            "run_command",
-            "get_command_output",
-            "create_terminal",
-            "wait_for_terminal_exit",
-            "kill_terminal",
-            "release_terminal",
-            "run_command_with_timeout",
-        }
-
-        # Should have all filesystem tools
-        expected_fs_tools = {"read_text_file", "write_text_file"}
-
-        assert expected_terminal_tools.issubset(tool_names)
-        assert expected_fs_tools.issubset(tool_names)
-        assert len(tools) == len(expected_terminal_tools) + len(expected_fs_tools)
-
-    async def test_provider_creates_only_terminal_tools_with_terminal_capabilities(
-        self, acp_agent: LLMlingACPAgent, terminal_only_capabilities: ClientCapabilities
-    ):
-        """Test provider creates only terminal tools when client only has terminal."""
-        provider = ACPCapabilityResourceProvider(
-            agent=acp_agent,
-            session_id="test_session",
-            client_capabilities=terminal_only_capabilities,
-        )
-
-        tools = await provider.get_tools()
-        tool_names = {tool.name for tool in tools}
-
-        # Should have terminal tools
-        expected_terminal_tools = {
-            "run_command",
-            "get_command_output",
-            "create_terminal",
-            "wait_for_terminal_exit",
-            "kill_terminal",
-            "release_terminal",
-            "run_command_with_timeout",
-        }
-
-        assert expected_terminal_tools.issubset(tool_names)
-
-        # Should NOT have filesystem tools
-        fs_tools = {"read_text_file", "write_text_file"}
-        assert not fs_tools.intersection(tool_names)
-
-    async def test_provider_creates_only_fs_tools_with_fs_capabilities(
-        self, acp_agent: LLMlingACPAgent, fs_only_capabilities: ClientCapabilities
-    ):
-        """Test provider creates only filesystem tools when client only has filesystem."""
-        provider = ACPCapabilityResourceProvider(
-            agent=acp_agent,
-            session_id="test_session",
-            client_capabilities=fs_only_capabilities,
-        )
-
-        tools = await provider.get_tools()
-        tool_names = {tool.name for tool in tools}
-
-        # Should have filesystem tools
-        expected_fs_tools = {"read_text_file", "write_text_file"}
-        assert expected_fs_tools.issubset(tool_names)
-
-        # Should NOT have terminal tools
-        terminal_tools = {
-            "run_command",
-            "get_command_output",
-            "create_terminal",
-            "wait_for_terminal_exit",
-            "kill_terminal",
-            "release_terminal",
-            "run_command_with_timeout",
-        }
-        assert not terminal_tools.intersection(tool_names)
-
-    async def test_provider_creates_no_tools_with_no_capabilities(
-        self, acp_agent: LLMlingACPAgent, no_capabilities: ClientCapabilities
-    ):
-        """Test provider creates no tools when client has no capabilities."""
-        provider = ACPCapabilityResourceProvider(
-            agent=acp_agent,
-            session_id="test_session",
-            client_capabilities=no_capabilities,
-        )
-
-        tools = await provider.get_tools()
-        assert len(tools) == 0
-
 
 class TestSessionScopedTerminalTools:
     """Test terminal tools with session-scoped functionality."""
@@ -271,7 +141,7 @@ class TestSessionScopedTerminalTools:
         result = await run_tool.execute(ctx=CTX, command="echo", args=["Hello World"])
 
         assert "Hello World" in result
-        assert "[Command exited with code 0]" in result
+        assert result == "Command completed with exit code 0:\nOutput:\nHello World\n"
 
         # Verify ACP calls were made with correct session_id
         agent = provider.agent
@@ -372,14 +242,14 @@ class TestSessionScopedTerminalTools:
     async def test_run_command_with_timeout_success(self, provider_with_tools):
         """Test run_command_with_timeout completes successfully."""
         _provider, tools = provider_with_tools
-        timeout_tool = tools["run_command_with_timeout"]
+        timeout_tool = tools["run_command"]
 
         result = await timeout_tool.execute(
             ctx=CTX, command="echo", args=["test"], timeout_seconds=5
         )
 
         assert "Hello World" in result
-        assert "[Command exited with code 0]" in result
+        assert result == "Command completed with exit code 0:\nOutput:\nHello World\n"
 
     async def test_terminal_error_handling(self, provider_with_tools):
         """Test terminal tool error handling."""
