@@ -8,7 +8,6 @@ from llmling import BasePrompt
 from llmling.config.models import ToolConfig
 from pydantic import ConfigDict, Field, ImportString
 from schemez import Schema
-from typing_extensions import TypeVar
 
 from llmling_agent.tools.base import Tool
 from llmling_agent_config.knowledge import Knowledge
@@ -18,10 +17,7 @@ if TYPE_CHECKING:
     from llmling_agent.agent import AnyAgent
 
 
-TResult = TypeVar("TResult", default=str)
-
-
-class Job[TDeps, TResult](Schema):
+class Job[TDeps, TResult = str](Schema):
     """A task is a piece of work that can be executed by an agent.
 
     Requirements:
