@@ -4,7 +4,7 @@ from __future__ import annotations
 
 from contextlib import contextmanager
 import os
-from typing import TYPE_CHECKING, Any, ParamSpec, TypeVar
+from typing import TYPE_CHECKING, Any
 
 from arize.otel import Transport, register
 from openinference.instrumentation import using_attributes
@@ -18,10 +18,6 @@ if TYPE_CHECKING:
     from collections.abc import Callable, Iterator
 
 
-P = ParamSpec("P")
-R = TypeVar("R")
-
-
 class ArizePhoenixProvider(ObservabilityProvider):
     """Observability provider using Arize Phoenix."""
 
@@ -70,7 +66,7 @@ class ArizePhoenixProvider(ObservabilityProvider):
 
         return wrapped
 
-    def wrap_action(
+    def wrap_action[R, **P](
         self,
         func: Callable[P, R],
         msg_template: str | None = None,
