@@ -1,14 +1,16 @@
+"""Langfuse prompt provider implementation."""
+
 from __future__ import annotations
 
 from typing import TYPE_CHECKING, Any
 
-from langfuse import Langfuse
+from langfuse import Langfuse  # pyright: ignore
 
 from llmling_agent.prompts.base import BasePromptProvider
 
 
 if TYPE_CHECKING:
-    from llmling_agent.models.prompt_hubs import LangfuseConfig
+    from llmling_agent_config.prompt_hubs import LangfuseConfig
 
 
 class LangfusePromptHub(BasePromptProvider):
