@@ -1,11 +1,18 @@
-from typing import Any
+"""OpenLIT prompt provider implementation."""
 
-import openlit
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Any
+
+import openlit  # pyright: ignore
 
-from llmling_agent.models.prompt_hubs import OpenLITConfig
 from llmling_agent.prompts.base import BasePromptProvider
 
 
+if TYPE_CHECKING:
+    from llmling_agent_config.prompt_hubs import OpenLITConfig
+
+
 class OpenLITProvider(BasePromptProvider):
     """Provider for prompts managed in OpenLIT."""
 
