@@ -1,19 +1,21 @@
-"""Prompt models for agent configuration."""
+"""PromptLayer prompt provider implementation."""
 
 from __future__ import annotations
 
 from typing import TYPE_CHECKING, Any
 
-from promptlayer import PromptLayer
+from promptlayer import PromptLayer  # pyright: ignore
 
 from llmling_agent.prompts.base import BasePromptProvider
 
 
 if TYPE_CHECKING:
-    from llmling_agent.models.prompt_hubs import PromptLayerConfig
+    from llmling_agent_config.prompt_hubs import PromptLayerConfig
 
 
 class PromptLayerProvider(BasePromptProvider):
+    """PromptLayer provider."""
+
     name = "promptlayer"
     supports_versions = True
 
