@@ -785,3 +785,43 @@ async def list_processes(ctx: AgentContext) -> str:
         return result.strip()
     except Exception as e:  # noqa: BLE001
         return f"Error listing processes: {e}"
+
+
+async def ask_user(  # noqa: D417
+    ctx: AgentContext,
+    prompt: str,
+    response_schema: dict[str, Any] | None = None,
+) -> str:
+    """Allow LLM to ask user a clarifying question during processing.
+
+    This tool enables agents to ask users for additional information or clarification
+    when needed to complete a task effectively.
+
+    Args:
+        prompt: Question to ask the user
+        response_schema: Optional JSON schema for structured response (defaults to string)
+
+    Returns:
+        The user's response as a string
+    """
+    from mcp.types import ElicitRequestParams, ElicitResult, ErrorData
+    from pydantic_ai.tools import RunContext
+
+    if isinstance(ctx, RunContext):
+        ctx = ctx.deps
+
+    schema = response_schema or {"type": "string"}  # string schema if no none provided
+    params = ElicitRequestParams(message=prompt, requestedSchema=schema)
+    result = await ctx.handle_elicitation(params)
+
+    match result:
+        case ElicitResult(action="accept", content=content):
+            return str(content)
+        case ElicitResult(action="cancel"):
+            return "User cancelled the request"
+        case ElicitResult():
+            return "User declined to answer"
+        case ErrorData(message=message):
+            return f"Error: {message}"
+        case _:
+            return "Unknown error occurred"
